<?php
/**
 * Create Magazine customizer default options
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */


/**
 * Returns the default options for create-magazine.
 *
 * @since Create Magazine 2.0
 * @return array An array of default values
 */
function create_magazine_get_default_theme_options() {

	$theme_data = wp_get_theme();

	$create_magazine_default_options = array(
		/**
		* Section Options
		*/
		//headline options
		'headline_enable'           			=> 'static-frontpage',
		'headline_title'       					=> esc_html__( 'Breaking News','create-magazine' ),
		'headline_type'							=> 'demo',
		'headline_no_of_posts'					=> 2,
		'headline_category_type'				=> '',
		
		//feature story options
		'featured_story_enable'     			=> 'static-frontpage',
		'featured_story_title'      			=> esc_html__( 'Feature-story','create-magazine' ),
		'num_of_featured_story'    				=> 4,
		'featured_story_type'					=> 'demo',
		'featured_story_content_category'		=> '',			
		'featured_story_content_tag'			=> '',
	
		//category block one options
		'featured_category_enable'       		=> 'static-frontpage',
		'featured_category_content_type' 		=> 'demo',
		'featured_category_no_of_posts'  		=> 3,
		
		// recent story options
		'recent_story_enable'             		=> 'static-frontpage',
		'recent_story_content_type'       		=> 'demo',
		'recent_story_title'              		=> esc_html__( 'Recent Story', 'create-magazine' ),
		'recent_story_content_category'   		=> '',

		//category block two options
		'category_block_one_enable'       		=> 'static-frontpage',
		'category_block_one_title'				=> esc_html__( 'Celebrity', 'create-magazine'),
		'category_block_one_content_type' 		=> 'demo',
		'category_block_one_no_of_posts'  		=> 3,
		'category_block_content_category' 		=> null,
		'category_block_content_tag'	  		=> null,

		//trending now options
		'trending_now_enable'     				=> 'static-frontpage',
		'trending_now_title'      				=> esc_html__('Trending-Now','create-magazine'),
		'num_of_trending_now'    				=> 8,
		'trending_now_type'						=> 'demo',
		'trending_now_content_category'			=> '',	
		'trending_now_content_tag'				=> '',

		//category block three options
		'category_block_two_enable'     		=> 'static-frontpage',
		'category_block_two_title'      		=> esc_html__( 'Culture','create-magazine' ),
		'num_of_category_block_two'    			=> 4,
		'category_block_two_type'				=> 'demo',
		'category_block_two_content_category'	=> '',
		'category_block_two_content_tag'		=> '',

		// Top categories options
		'top_categories_enable'					=> 'static-frontpage',
		'top_categories_content_type'			=> 'demo',	
		'top_categories_title'					=> esc_html__( 'Top Categories', 'create-magazine' ),
		'top_categories_no_of_posts'			=> 3,
		'top_categories_content_category'		=> null,	

		// category block four options 
		'category_block_three_enable'			=> 'static-frontpage',
		'category_block_three_content_type'		=> 'demo',
		'category_block_three_title'			=> esc_html__( 'Fashion', 'create-magazine' ),
		'category_block_three_content_category'	=> null,

		//photo gallery
		'gallery_enable'						=> 'static-frontpage',
		'gallery_title'							=> esc_html__( 'Photo Gallery','create-magazine' ),
		'gallery_title_url'						=> '',
		'num_gallery_image'						=> 4,
		'gallery_type'							=> 'demo',	

		// Contact Details
		'contact_details_enable'				=> 'static-frontpage',
		'telephone'								=> '',
		'location'								=> '',
		'email'									=> '',

		//theme options
		'excerpt_length'           				=> 15,
		'enable_pagination'        				=> true,
		'pagination_type'          				=> 'numeric',
		'sidebar_position'         				=> 'right-sidebar',
		'site_layout'         					=> 'wide',
		'site_animation_layout'					=> true,		
		'reset_options'      					=> false,
		'enable_frontpage_content' 				=> true,
		
		'copyright_text'           				=> sprintf( esc_html__( 'Copyright &copy; . All Rights Reserved','create-magazine' ) ) . ' &#124; ' . $theme_data->get( 'Name') . '&nbsp;' . esc_html__( 'by', 'create-magazine' ). '&nbsp;<a target="_blank" href="'. $theme_data->get( 'AuthorURI' ) .'">'. $theme_data->get( 'Author' ) .'</a>',
		'disable_primary_menu'	   				=> '',
		'disable_search'		   				=> '',
		'disable_scroll'		   				=> '',
		'move_title_tagline'	   				=> '',
		'loader_enable'            				=> false,
		'loader_type'			   				=> 'icon',
		'loader_icon_type'		   				=> 'fa-circle-o-notch',
		'loader_image_type'		   				=> get_template_directory_uri() . '/assets/images/loader-image.gif',
		'search_text'			   				=> esc_html__( 'Search..','create-magazine' ),
		'readmore_text'							=> esc_html__( 'Read More..','create-magazine' ),
		// archive sticky category
		'create_magazine_archive_category'		=> 1,
		'theme_color'							=> 'default',

		// theme options
		'disable_related_posts'					=> false,
		'related_posts_title'					=> esc_html__( 'you may also like', 'create-magazine' ),
	);

	$output = apply_filters( 'create_magazine_default_theme_options', $create_magazine_default_options );
	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}