<?php
/**
 * Category block one Customizer options
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */

// Add category block one section
$wp_customize->add_section( 'create_magazine_category_block_one_section', array(
	'title'       		=> esc_html__( 'Category Block one','create-magazine' ),
	'description' 		=> esc_html__( 'Category block one section options.', 'create-magazine' ),
	'priority'			=> '50',
	'panel'       		=> 'create_magazine_sections_panel'
) );

// Add category block one  enable setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[category_block_one_enable]', array(
	'default'         	=> $options['category_block_one_enable'],
	'sanitize_callback' => 'create_magazine_sanitize_select'
) );

$wp_customize->add_control( 'create_magazine_theme_options[category_block_one_enable]', array(
	'label'             => esc_html__( 'Enable on', 'create-magazine' ),
	'section'           => 'create_magazine_category_block_one_section',
	'priority'			=> '10',
	'type'              => 'select',
	'choices'           => create_magazine_enable_options()
) );

// Add Category block one title setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[category_block_one_title]', array(
	'default'           => $options['category_block_one_title'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'create_magazine_theme_options[category_block_one_title]', array(
	'label'             => esc_html__( 'Title', 'create-magazine' ),
	'section'           => 'create_magazine_category_block_one_section',
	'type'              => 'text',
	'active_callback'	=> 'create_magazine_is_category_block_one_demo_content_active'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'create_magazine_theme_options[category_block_one_title]', array(
		'selector'            => '#celebrities .celebrities-wrapper h2.entry-title',
		'render_callback'     => 'create_magazine_customize_partial_category_block_one_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add category block one content type setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[category_block_one_content_type]', array(
	'default'           => $options['category_block_one_content_type'],
	'sanitize_callback' => 'create_magazine_sanitize_select'
) );

$wp_customize->add_control( 'create_magazine_theme_options[category_block_one_content_type]', array(
	'label'           => esc_html__( 'Content Type', 'create-magazine' ),
	'section'         => 'create_magazine_category_block_one_section',
	'priority'		  => '20',
	'type'            => 'select',
	'active_callback' => 'create_magazine_is_category_block_one_active',
	'choices'         => array(
		'demo'		  => esc_html__( 'Demo', 'create-magazine' ),
		'post'		  => esc_html__( 'Posts', 'create-magazine' ),
		'category'	  => esc_html__( 'Category', 'create-magazine' ),
		'tag'		  => esc_html__( 'Tags', 'create-magazine' ),

	)
) );

// Add category block one section and control to show no of posts 
$wp_customize->add_setting( 'create_magazine_theme_options[category_block_one_no_of_posts]', array(
	'default'           => $options['category_block_one_no_of_posts'],
	'sanitize_callback' => 'create_magazine_sanitize_number_range'
) );

$wp_customize->add_control( 'create_magazine_theme_options[category_block_one_no_of_posts]', array(
	'label'           => esc_html__( 'No of posts', 'create-magazine' ),
	'description'	  => esc_html__( 'Save and refresh page after changing value', 'create-magazine' ),
	'section'         => 'create_magazine_category_block_one_section',
	'priority'		  => '30',
	'active_callback' => 'create_magazine_is_category_block_one_demo_content_active',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'          	=> 1,
		'max'			=> 3,
		'style'        	=> 'width: 80px;'
	)
) );

$no_of_post = $options['category_block_one_no_of_posts'];

for( $i = 1; $i<= $no_of_post; $i++ ){
	// Add category block one post setting and control
	$wp_customize->add_setting( 'create_magazine_theme_options[category_block_one_content_post_'. $i .']', array(
		'sanitize_callback' => 'create_magazine_sanitize_number_range',

	) );

	$wp_customize->add_control( 'create_magazine_theme_options[category_block_one_content_post_'. $i .']', array(
		'label'           	=> esc_html__( 'Post #', 'create-magazine' ). $i,
		'description'	  	=> esc_html__( 'Enter post ID', 'create-magazine' ),
		'section'         	=> 'create_magazine_category_block_one_section',
		'priority'		  	=> '5'. $i,
		'active_callback' 	=> 'create_magazine_is_category_block_one_post_content_active',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'placeholder'			=> esc_attr__( 'Post Id', 'create-magazine' ),
			'style'			=> 'width:80px',
		)
	) );
}

// Add category block one posts from category setting and control
$wp_customize->add_setting( 'create_magazine_theme_options[category_block_content_category]', array(
	'default'           => $options['category_block_content_category'],
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Create_Magazine_Dropdown_Category_Control( $wp_customize, 'create_magazine_theme_options[category_block_content_category]', array(
	'label'           => esc_html__( 'Category', 'create-magazine' ),
	'description'	  => esc_html__( 'Select category to display posts', 'create-magazine' ),
	'section'         => 'create_magazine_category_block_one_section',
	'priority'		  => '60',
	'active_callback' => 'create_magazine_is_category_block_one_category_content_active',
	'type'				=> 'dropdown-category',
	'input_attrs'		=> array(
		'style'        	=> 'width: 80px;'
	)
) ) );

// Add category block one posts from tags setting and control
$wp_customize->add_setting( 'create_magazine_theme_options[category_block_content_tag]', array(
	'default'           => $options['category_block_content_tag'],
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Create_Magazine_Dropdown_Tag_Control ( $wp_customize, 'create_magazine_theme_options[category_block_content_tag]', array(
	'label'           => esc_html__( 'Tag', 'create-magazine' ),
	'description'	  => esc_html__( 'Select tags to display posts', 'create-magazine' ),
	'section'         => 'create_magazine_category_block_one_section',
	'priority'		  => '60',
	'active_callback' => 'create_magazine_is_category_block_one_tag_content_active',
	'type'				=> 'dropdown-tag',
	'input_attrs'		=> array(
		'style'        	=> 'width: 80px;'
	)
) ) );
