<?php
/**
 * Featured category Customizer options
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */

// Add Featured category section
$wp_customize->add_section( 'create_magazine_featured_category_section', array(
	'title'       		=> esc_html__( 'Featured category','create-magazine' ),
	'description' 		=> esc_html__( 'Featured category section options. Recommended image thumbnail size 390x506 px.', 'create-magazine' ),
	'priority'			=> '20',
	'panel'       		=> 'create_magazine_sections_panel'
) );

// Add Featured category enable setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[featured_category_enable]', array(
	'default'         	=> $options['featured_category_enable'],
	'sanitize_callback' => 'create_magazine_sanitize_select'
) );

$wp_customize->add_control( 'create_magazine_theme_options[featured_category_enable]', array(
	'label'             => esc_html__( 'Enable on', 'create-magazine' ),
	'section'           => 'create_magazine_featured_category_section',
	'priority'			=> '10',
	'type'              => 'select',
	'choices'           => create_magazine_enable_on_entire_site_options()
) );

// Add Featured category content type setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[featured_category_content_type]', array(
	'default'           => $options['featured_category_content_type'],
	'sanitize_callback' => 'create_magazine_sanitize_select'
) );

$wp_customize->add_control( 'create_magazine_theme_options[featured_category_content_type]', array(
	'label'           => esc_html__( 'Content Type', 'create-magazine' ),
	'section'         => 'create_magazine_featured_category_section',
	'priority'		  => '20',
	'type'            => 'select',
	'active_callback' => 'create_magazine_is_featured_category_active',
	'choices'         => array(
		'demo'		  => esc_html__( 'Demo', 'create-magazine' ),
		'page'		  => esc_html__( 'Page', 'create-magazine' ),
		'post'		  => esc_html__( 'Post', 'create-magazine' ),
	)
) );

// Add Featured category section and control to show no of posts
$wp_customize->add_setting( 'create_magazine_theme_options[featured_category_no_of_posts]', array(
	'default'           => $options['featured_category_no_of_posts'],
	'sanitize_callback' => 'create_magazine_sanitize_number_range'
) );

$wp_customize->add_control( 'create_magazine_theme_options[featured_category_no_of_posts]', array(
	'label'           => esc_html__( 'No of posts', 'create-magazine' ),
	'description'	  => esc_html__( 'Save and refresh page after changing value. Min = 2 and Max = 3', 'create-magazine' ),
	'section'         => 'create_magazine_featured_category_section',
	'priority'		  => '30',
	'active_callback' => 'create_magazine_is_featured_category_demo_content_active',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'          	=> 2,
		'max' 			=> 3,
		'style'        	=> 'width: 80px;'
	)
) );

$no_of_post = $options['featured_category_no_of_posts'];

for( $i = 1; $i<= $no_of_post; $i++ ){
	// Featured category Show page drop-down setting and control
	$wp_customize->add_setting( 'create_magazine_theme_options[featured_category_content_page_'. $i .']', array(
		'sanitize_callback' => 'create_magazine_sanitize_page'
	) );

	$wp_customize->add_control( 'create_magazine_theme_options[featured_category_content_page_'. $i .']', array(
		'label'           => esc_html__( 'Page #', 'create-magazine' ). $i,
		'section'         => 'create_magazine_featured_category_section',
		'priority'		  => '4'.$i,
		'active_callback' => 'create_magazine_is_featured_category_page_content_active',
		'type'            => 'dropdown-pages'
	) );

	// Add Featured category post setting and control
	$wp_customize->add_setting( 'create_magazine_theme_options[featured_category_content_post_'. $i .']', array(
		'sanitize_callback' => 'create_magazine_sanitize_number_range'
	) );

	$wp_customize->add_control( 'create_magazine_theme_options[featured_category_content_post_'. $i .']', array(
		'label'           	=> esc_html__( 'Post #', 'create-magazine' ). $i,
		'description'	  	=> esc_html__( 'Enter post ID', 'create-magazine' ),
		'section'         	=> 'create_magazine_featured_category_section',
		'priority'		  	=> '5'. $i,
		'active_callback' 	=> 'create_magazine_is_featured_category_post_content_active',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'			=> 1,
			'style'			=> 'width:80px',
		)
	) );
}

