<?php
/**
 * Photo gallery Customizer options
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */

// Add Photo Gallery enable section
$wp_customize->add_section( 'create_magazine_gallery_section', array(
	'title'             => esc_html__( 'Photo Gallery','create-magazine' ),
	'description'       => esc_html__( 'Photo Gallery section options.', 'create-magazine' ),
	'priority'			=> '90',
	'panel'             => 'create_magazine_sections_panel'
) );

// Add photo gallery enable setting and control.
$wp_customize->add_setting( 'create_magazine_theme_options[gallery_enable]', array(
	'default'           => $options['gallery_enable'],
	'sanitize_callback' => 'create_magazine_sanitize_select'
) );

$wp_customize->add_control( 'create_magazine_theme_options[gallery_enable]', array(
	'label'             => esc_html__( 'Enable on', 'create-magazine' ),
	'section'           => 'create_magazine_gallery_section',
	'type'              => 'select',
	'choices'           => create_magazine_enable_options()
) );

// Add photo gallery title
$wp_customize->add_setting( 'create_magazine_theme_options[gallery_title]', array(
	'default'           => $options['gallery_title'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'create_magazine_theme_options[gallery_title]', array(
	'label'             => esc_html__( 'Gallery Title', 'create-magazine' ),
	'section'           => 'create_magazine_gallery_section',
	'type'              => 'text',
	'active_callback'	=> 'create_magazine_photo_gallery_type'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'create_magazine_theme_options[gallery_title]', array(
		'selector'            => '#photo-gallery h2.entry-title',
		'render_callback'     => 'create_magazine_customize_partial_gallery_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add photo gallery title url
$wp_customize->add_setting( 'create_magazine_theme_options[gallery_title_url]', array(
	'default'           => $options['gallery_title_url'],
	'sanitize_callback' => 'esc_url'
) );

$wp_customize->add_control( 'create_magazine_theme_options[gallery_title_url]', array(
	'label'             => esc_html__( 'Gallery Title Link', 'create-magazine' ),
	'section'           => 'create_magazine_gallery_section',
	'type'              => 'url',
	'active_callback'	=> 'create_magazine_photo_gallery_type'
) );

// Add photo gallery no. of images
$wp_customize->add_setting( 'create_magazine_theme_options[num_gallery_image]', array(
	'default'           => $options['num_gallery_image'],
	'sanitize_callback' => 'create_magazine_sanitize_number_range'
) );

$wp_customize->add_control( 'create_magazine_theme_options[num_gallery_image]', array(
	'label'             => esc_html__( 'No of Images', 'create-magazine' ),
	'description'		=> esc_html__( 'Max 8 Images. Save and referesh the page to add photo after changing value.', 'create-magazine' ),
	'section'           => 'create_magazine_gallery_section',
	'input_attrs' 		=> array( 'min' => 4, 'max' => 8, 'style' => 'width: 100px;' ),
	'type'              => 'number',
	'active_callback'   => 'create_magazine_photo_gallery_type'
) );

// Add photo gallery source type
$wp_customize->add_setting( 'create_magazine_theme_options[gallery_type]', array(
	'default'           => $options['gallery_type'],
	'sanitize_callback' => 'create_magazine_sanitize_select'
) );

$wp_customize->add_control( 'create_magazine_theme_options[gallery_type]', array(
	'label'             => esc_html__( 'Gallery Source', 'create-magazine' ),
	'section'           => 'create_magazine_gallery_section',
	'type'              => 'select',
	'choices'           => create_magazine_photo_gallery_options(),
	'active_callback'	=> 'create_magazine_photo_gallery_active'
) );


$value = create_magazine_get_theme_options();
$no_of_images = $value['num_gallery_image'];

for ( $i = 1; $i <= $no_of_images; $i++ ) {
	// Add photo gallery image
	$wp_customize->add_setting( 'create_magazine_theme_options[gallery_image_'. $i .']',
	  array(
	    'sanitize_callback' 	=> 'create_magazine_sanitize_image',
	  )
	);
	$wp_customize->add_control(
	  new WP_Customize_Image_Control( $wp_customize, 'create_magazine_theme_options[gallery_image_'. $i .']',
	    array(
	    	'label'      		=> esc_html__( 'Upload a gallery image #', 'create-magazine' ) . $i,
	        'section'    		=> 'create_magazine_gallery_section',
			'settings'    		=> 'create_magazine_theme_options[gallery_image_'. $i .']',
			'active_callback'	=> 'create_magazine_photo_gallery_type',
	    )
	  )
	);

	// Add photo gallery alt tag for image
	$wp_customize->add_setting( 'create_magazine_theme_options[gallery_image_alt_' . $i . ']', array(
	'sanitize_callback' 	=> 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'create_magazine_theme_options[gallery_image_alt_' . $i . ']', array(
		'label'             => esc_html__( 'Image Alt Text', 'create-magazine' ),
		'section'           => 'create_magazine_gallery_section',
		'type'              => 'text',
		'active_callback'	=> 'create_magazine_photo_gallery_type'
	) );
}