<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Theme Palace
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function create_magazine_body_classes( $classes ) {
	$options = create_magazine_get_theme_options();
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

    $sidebar_position = create_magazine_layout();
    
    $classes[] = esc_attr( $sidebar_position );

	$classes[] = esc_attr( $options['site_layout'] );

	return $classes;
}
add_filter( 'body_class', 'create_magazine_body_classes' );

if ( ! function_exists( 'create_magazine_add_search_box_to_menu' ) ) :
    /**
     * Add search box to menu
     * @param  
   * * @return 
     */

    function create_magazine_add_search_box_to_menu( $items, $args ) {
        
        $options = create_magazine_get_theme_options();
        $disable_search = $options['disable_search'];
        if( $args->theme_location == 'primary' ) {        

           // Search Box
            if ( $disable_search ) {
                $search = '';
                $html = $items;
            } 
            else {
                $search =   '<div class="search">
                                '.get_search_form(false).'
                            </div>';
                $html = $items.$search;
            }

            return $html;      
        }
        return $items;
    }
endif;
add_filter('wp_nav_menu_items','create_magazine_add_search_box_to_menu', 10, 2);


if ( ! function_exists( 'create_magazine_mobile_nav_menu' ) ) :

    /**
     * Add mobile menuin responsive mode       
     */

    function create_magazine_mobile_nav_menu() { ?>
        <!-- Mobile Menu -->
        <nav id="sidr-left-top" class="mobile-menu sidr left">
            <?php 
                if ( has_custom_logo( ) ) : ?>
                <div class="site-branding">
                    <a href="<?php echo esc_url( home_url( '/' ) ); ?> ">
                        <?php echo get_custom_logo();?>
                    </a>
                </div><!-- end .site-branding -->
            <?php endif; 

            if ( has_nav_menu( 'primary' ) ) {
                wp_nav_menu( array( 'theme_location' => 'primary','container' => false,
                    'depth' => 3, ) );
            }
            ?>
        </nav><!-- end left-menu -->

        <a id="sidr-left-top-button" class="menu-button right" href="#sidr-left-top"><i class="fa fa-bars"></i></a>
        <?php
    }
endif;
add_action( 'create_magazine_header', 'create_magazine_mobile_nav_menu', 110 );

/**
 * Get an attachment ID given a URL.
 * 
 * @param string $image_src
 *
 * @return int Attachment ID on success, 0 on failure
 */
function create_magazine_get_attachment_id_from_src( $image_src ) {
    $attachment_id = 0;
    $dir = wp_upload_dir();
    if ( false !== strpos( $image_src, $dir['baseurl'] . '/' ) ) { // Is URL in uploads directory?
        $file = basename( $image_src );
        $query_args = array(
            'post_type'   => 'attachment',
            'post_status' => 'inherit',
            'fields'      => 'ids',
            'meta_query'  => array(
                array(
                    'value'   => $file,
                    'compare' => 'LIKE',
                    'key'     => '_wp_attachment_metadata',
                ),
            )
        );

        $query = new WP_Query( $query_args );
        if ( $query->have_posts() ) {
            foreach ( $query->posts as $post_id ) {
                $meta = wp_get_attachment_metadata( $post_id );
                $original_file       = basename( $meta['file'] );
                $cropped_image_files = wp_list_pluck( $meta['sizes'], 'file' );
                if ( $original_file === $file || in_array( $file, $cropped_image_files ) ) {
                    $attachment_id = $post_id;
                    break;
                }
            }
        wp_reset_postdata();
        }
    }
    return $attachment_id;
}