<?php
/**
 * Category block three section
 *
 * This is the template for the content of category block three section
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */

if ( ! function_exists( 'create_magazine_add_category_block_three_section' ) ) :
    /**
     * Add category block three section
     *
     * @since 2.0
     */
    function create_magazine_add_category_block_three_section() {

        // Check if Category Block three is enabled 
        $category_block_three_enable = apply_filters( 'create_magazine_section_status', true, 'category_block_three_enable' );
        if ( true !== $category_block_three_enable ) {
            return false;
        }

        // Get Category Block three section details
        $section_details = array();
        $section_details = apply_filters( 'create_magazine_filter_category_block_three_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Category Block three section now.
       create_magazine_render_category_block_three_section( $section_details );
      }
endif;
add_action( 'create_magazine_primary_content', 'create_magazine_add_category_block_three_section', 100 );

if ( ! function_exists( 'create_magazine_get_category_block_three_section_details' ) ) :
    /**
     * category block three section details.
     *
     * @since 2.0
     *
     * @param array $input category block three section details.
     */
    function create_magazine_get_category_block_three_section_details( $input ) {

        $options = create_magazine_get_theme_options();
        $content = array();

        switch ( $options['category_block_three_content_type'] ) {

            case 'demo':

                $image   = array( 'fashion-01.jpg','fashion-02.jpg' );// An array of demo image
                $title   = array( esc_html__( 'Illustration whizz Andy Rementer talks us through the common...','create-magazine' ), esc_html__( 'When youre like I have nothing to wear LOL: Aussie street artist...','create-magazine' ) );// An array of demo title

                for( $i = 0; $i < 2; $i++ ) {
                    $content[$i]['img_array']= array( get_template_directory_uri().'/assets/images/'.$image[$i] );
                    $content[$i]['url']      = '#';
                    $content[$i]['title']    = $title[$i];
                    $content[$i]['excerpt']  = esc_html__( 'Adipisicing elit, lispum sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.', 'create-magazine' );
                    $content[$i]['date']     = esc_html__( 'FEB 22 2016','create-magazine' );
                } 
            break;
            
            case 'category':
                $category = !empty ( $options['category_block_three_content_category'] ) ? absint( $options['category_block_three_content_category'] ) : '';
                
                if ( ! empty( $category ) ) {
                
                    $args = array(
                        'cat'               => $category,
                        'posts_per_page'    => 2,
                        'posts_status'      => 'publish'
                    );
                }
            break;
           
        }
        if( $options['category_block_three_content_type'] != 'demo'  ) :
            
            if( ! empty ( $args ) ) :
                $custom_posts = get_posts( $args );

                $i = 0;
                foreach ( $custom_posts as $key => $custom_post ) {
                    
                    $img_array = null;

                    if ( has_post_thumbnail( $custom_post->ID ) ) {
                        
                        $thumbnail_size = 'create-magazine-top-categories-large';                
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), $thumbnail_size );
                          $content[$i]['img_array'] = $img_array;
                    } 
                    $content[$i]['url']      = get_permalink( $custom_post->ID );
                    $content[$i]['title']    = get_the_title( $custom_post->ID );
                    $content[$i]['excerpt']  = create_magazine_trim_content( $custom_post, absint( $options['excerpt_length'] ) );
                    $content[$i]['date']     = get_the_date( '', $custom_post->ID );
                $i++;
                }
            endif;
        endif;
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
    return $input;      
    }
endif;
// category block three section content details.
add_filter( 'create_magazine_filter_category_block_three_section_details', 'create_magazine_get_category_block_three_section_details' );

if ( ! function_exists( 'create_magazine_render_category_block_three_section' ) ) :
    /**
     * Start section category block three
     *
     * @return string category block three content
     * @since Create Magazine 2.0
     *
     */
    function create_magazine_render_category_block_three_section( $section_details = array() ) {
        $options = create_magazine_get_theme_options();

        if ( empty( $section_details ) ) {
            return;
        } 
        if( is_active_sidebar( 'category-block-sidebar-3' ) ) :
            $create_magazine_no_section_sidebar   = '';
        else :
            $create_magazine_no_section_sidebar   = 'no-section-sidebar';
        endif;
        ?>
        <section id="fashion" class="<?php echo esc_attr( $create_magazine_no_section_sidebar ); ?>">
            <div class="container page-section">
                <div class="main-content gridview two-col widget-category">
                <?php $section_title = ( $options['category_block_three_content_type'] == 'demo') ? esc_html__( 'fashion','create-magazine') : $options['category_block_three_title'];
                    
                    if( !empty( $section_title ) ) : ?>
                    <header class="entry-header text-left">
                        <h2 class="entry-title color-black os-animation" data-os-animation="fadeInDown" data-os-animation-delay="0.3s" data-os-animation-duration="1s"><?php echo esc_html( $section_title ); ?></h2>
                    </header>
                    <?php endif; ?>
                    <?php foreach ( $section_details as $key => $section_detail ) { ?>
                    <div class="column-wrapper">
                        <div class="blog-post">

                        <?php if( isset(  $section_detail['img_array'] ) ){ ?>
                            <div class="category-image os-animation" data-os-animation="fadeIn" data-os-animation-delay="0.3s" data-os-animation-duration="0.6s">
                                <a href="<?php echo esc_url( $section_detail['url'] ); ?>"><img src="<?php echo esc_url( $section_detail['img_array'][0] ); ?>" alt="<?php echo esc_html( $section_detail['title'] ); ?>"><div class="overlay-blue"></div></a>
                            </div>
                        <?php } ?>

                            <div class="category-desc">
                                <span class="date os-animation" data-os-animation="fadeInUp" data-os-animation-delay="0.3s" data-os-animation-duration="0.6s"><?php echo esc_html( $section_detail['date'] ); ?></span>

                                <a href="<?php echo esc_url( $section_detail['url'] ); ?>"><h2 class="os-animation" data-os-animation="fadeInDown" data-os-animation-delay="0.3s" data-os-animation-duration="0.6s"><?php echo esc_html( $section_detail['title'] ); ?></h2></a>

                                <?php if( !empty( $section_detail['excerpt'] ) ) { ?> 
                                <p class="os-animation" data-os-animation="fadeInUp" data-os-animation-delay="0.3s" data-os-animation-duration="0.6s"><?php echo esc_html( $section_detail['excerpt'] ); ?></p>
                                <?php } ?>
                                <a href="<?php echo esc_url( $section_detail['url'] ); ?>" class="read-more os-animation" data-os-animation="fadeIn" data-os-animation-delay="0.4s" data-os-animation-duration="0.3s"><i class="fa fa-caret-right"></i><?php echo esc_html( $options['readmore_text'] ); ?></a>
                            </div><!-- end .blog-desc -->
                        </div><!-- end .blog-post-->
                        </div><!-- end .column-wrapper -->
                    <?php } ?>

                    <?php if( is_active_sidebar( 'category-block-three-bottom-widget' ) ){  ?>
                        <div class="clear"> </div>
                        <div class="widget-google-ad os-animation" data-os-animation="flipInX" data-os-animation-delay="0.3s" data-os-animation-duration="1s">
                            <?php dynamic_sidebar( 'category-block-three-bottom-widget' ); ?>
                        </div><!-- end .widget-google-ad -->
                    <?php } ?>

                </div><!-- end .main-content -->
                <?php
                    if( is_active_sidebar( 'category-block-sidebar-3' ) ){  ?>
                        <div class="sidebar bg-white os-animation" data-os-animation="fadeInUp" data-os-animation-delay="0.1s" data-os-animation-duration="0.6s">
                            <?php dynamic_sidebar( 'category-block-sidebar-3' ); ?>
                        </div><!-- end .sidebar -->
                <?php  } ?>
            </div><!-- .container -->
            <div class="clear"></div>
        </section><!-- end #fashion -->
<?php
    }
endif;