<?php
/**
 * Category Block two section
 *
 * This is the template for the content of Category Block two section in front page
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */
if ( ! function_exists( 'create_magazine_add_category_block_two_section' ) ) :
    /**
     * Add Category Block two section
     *
     * @since 2.0
     */
    function create_magazine_add_category_block_two_section() {

        // Check if Category Block two is enabled 
        $category_block_two_enable = apply_filters( 'create_magazine_section_status', true, 'category_block_two_enable' );
        if ( true !== $category_block_two_enable ) {
            return false;
        }

        // Get Category Block two section details
        $section_details = array();
        $section_details = apply_filters( 'create_magazine_filter_category_block_two_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Category Block two section now.
        create_magazine_render_category_block_two_section( $section_details );
    }
endif;
add_action( 'create_magazine_primary_content', 'create_magazine_add_category_block_two_section', 80 );


if ( ! function_exists( 'create_magazine_get_category_block_two_section_details' ) ) :
    /**
     * category block two section details.
     *
     * @since 2.0
     *
     * @param array $input category block two section details.
     */
    function create_magazine_get_category_block_two_section_details( $input ) {

      $options = create_magazine_get_theme_options();
        $content = array();
        $no_of_post = absint( $options['num_of_category_block_two'] );

        switch ( $options['category_block_two_type'] ) {

            case 'demo':

                $image   = array( 'culture-01.jpg','culture-02.jpg','culture-03.jpg','culture-04.jpg' );// An array of demo image
                $title   = array( esc_html__( 'The Birthday Tradition You Should Start Immediately','create-magazine' ),esc_html__( 'Girl\'s Hilarious Extra Credit Answer Goes Viral','create-magazine' ),esc_html__( 'Put on Your Judgment Hat: People Is Back!','create-magazine' ),esc_html__( 'The Birthday Tradition You Should Start Immediately','create-magazine' ) );// An array of demo title

                for( $i=0;$i<4;$i++) {
                    $content[$i]['img_array']= array( get_template_directory_uri().'/assets/images/'.$image[$i] );
                    $content[$i]['url']      = '#';
                    $content[$i]['title']    = $title[$i];
                    $content[$i]['excerpt']  = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco', 'create-magazine' );
                    $content[$i]['date']     = esc_html__( 'FEB 22 2016','create-magazine' );
                }                
            break;
            
            case 'category':
                $category = !empty ( $options['category_block_two_content_category'] ) ? absint( $options['category_block_two_content_category'] ) : '';
                
                if ( ! empty( $category ) ) {
                
                    $args = array(
                        'cat'               => $category,
                        'posts_per_page'    => $no_of_post
                    );
                }
            break;
            
            case 'tag':

                $tag = !empty ( $options['category_block_two_content_tag'] ) ? absint( $options['category_block_two_content_tag'] ) : '';

                if ( ! empty( $tag ) ) {

                    $args = array(
                        'tag_id'            => $tag,
                        'posts_per_page'    => $no_of_post
                    );
                }                    
            break;

            case 'post':
                $post_list = array();
                for ( $i = 1; $i <= $no_of_post ; $i++ ) { 
                    $post_id    = ! empty ( $options['category_block_two_post_id_' . $i] ) ? absint( $options['category_block_two_post_id_' . $i] ) : '';
                    $post_list  = array_merge( $post_list, array( $post_id ) );
                }

                if ( ! empty( $post_list ) ) {
                
                    $args = array(
                        'post__in'           => $post_list,
                        'posts_per_page'    => $no_of_post,
                    );
                }
            break;

            default:
            break;          
        }
        if( $options['category_block_two_type'] != 'demo'  ) :
            
            if( ! empty ( $args ) ) :
                
                
                $custom_posts = get_posts( $args );

                $i = 0;
                foreach ( $custom_posts as $key => $custom_post ) {
                    
                    $img_array = null;

                    if ( has_post_thumbnail( $custom_post->ID ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'create-magazine-top-categories-large' );
                        $content[$i]['img_array'] = $img_array;
                    } 

                    $content[$i]['url']      = get_permalink( $custom_post->ID );
                    $content[$i]['title']    = get_the_title( $custom_post->ID );
                    $content[$i]['excerpt']  = create_magazine_trim_content( $custom_post, absint( $options['excerpt_length'] ) );
                    $content[$i]['date']     = get_the_date( '', $custom_post->ID );
                $i++;
                }
            endif;
        endif;
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
    return $input;      
    }
endif;
// category block two section content details.
add_filter( 'create_magazine_filter_category_block_two_section_details', 'create_magazine_get_category_block_two_section_details' );

if ( ! function_exists( 'create_magazine_render_category_block_two_section' ) ) :
    /**
     * Start section category block two
     *
     * @return string category block two content
     * @since Create Magazine 2.0
     *
     */
    function create_magazine_render_category_block_two_section( $content_details = array() ) {
        $options = create_magazine_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } 
        if( is_active_sidebar( 'category-block-sidebar-2' ) ) :
            $create_magazine_no_section_sidebar   = '';
        else :
            $create_magazine_no_section_sidebar   = 'no-section-sidebar';
        endif;
        ?>

        <section id="culture" class="<?php echo esc_attr( $create_magazine_no_section_sidebar ); ?>">
            <?php $section_title = ( $options['category_block_two_type'] == 'demo') ? esc_html__('Culture','create-magazine') : $options['category_block_two_title'];
            if(! empty( $section_title ) ) : ?>
            <div class="container page-section">
                <div class="main-content widget-category">
                   <header class="entry-header os-animation" data-os-animation="fadeInDown" data-os-animation-delay="0.3s" data-os-animation-duration="1s">
                      <h2 class="entry-title color-black"><?php echo esc_html( $section_title );?></h2>
                  </header><!-- end .entry-header -->
                <?php endif; ?>
                    
                    <?php foreach( $content_details as $content) :
                    $class = !empty( $content['img_array'][0] ) ? '' : 'no-post-thumbnail';?>
                    <div class="blog-post <?php echo esc_attr( $class ); ?>">
                        <?php if( !empty( $content['img_array'][0] ) ) : ?>
                        <div class="category-image os-animation" data-os-animation="fadeIn" data-os-animation-delay="0.3s" data-os-animation-duration="0.6s">
                          <a href="<?php echo esc_url( $content['url'] );?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_html( $content['title'] ); ?>">
                          <div class="overlay-blue"></div></a>
                        </div>
                        <?php endif; ?>
                     
                        <div class="category-desc">
                            <?php if( !empty( $content['date'] ) ) : ?>
                          <span class="date os-animation" data-os-animation="fadeInUp" data-os-animation-delay="0.3s" data-os-animation-duration="0.6s"><?php echo esc_html( $content['date'] ); ?></span>
                            <?php endif; ?>
                            
                            <?php if( !empty( $content['title'] ) ) : ?>
                          <a href="<?php echo esc_url( $content['url'] );?>">
                          <h2 class="os-animation" data-os-animation="fadeInDown" data-os-animation-delay="0.3s" data-os-animation-duration="0.6s"><?php echo esc_html( $content['title'] ); ?></h2></a>
                            <?php endif; ?>
                          
                            <?php if( !empty( $content['excerpt'] ) ) : ?>
                            <p class="os-animation" data-os-animation="fadeInUp" data-os-animation-delay="0.3s" data-os-animation-duration="0.6s"><?php echo esc_html( $content['excerpt'] ); ?></p>
                            <?php endif; ?>

                            <?php if( !empty( $content['excerpt'] ) ) : ?>
                              <a href="<?php echo esc_url( $content['url'] ); ?>" class="read-more os-animation" data-os-animation="fadeIn" data-os-animation-delay="0.4s" data-os-animation-duration="0.3s"><i class="fa fa-caret-right"></i><?php echo esc_html( $options['readmore_text'] ); ?></a>
                            <?php endif; ?>
                        </div><!-- end .category-desc -->
                        <div class="clear"></div>
                    </div><!-- end .blog-post-->
                    <?php endforeach; ?>
                </div><!-- end .main-content-->
                <?php
                    if( is_active_sidebar( 'category-block-sidebar-2' ) ) : ?>
                        <div class="sidebar bg-white">
                            <?php dynamic_sidebar( 'category-block-sidebar-2' ); ?>
                        </div><!-- end .sidebar -->
                    <?php endif;  
                ?>
                </div><!-- .container -->
            <div class="clear"></div>
        </section><!-- end #culture -->
<?php
    }
endif;