<?php
/**
 * Photo gallery section
 *
 * This is the template for the content of photo gallery section
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */

if ( ! function_exists( 'create_magazine_add_gallery_section' ) ) :
    /**
     * Add gallery section
     *
     * @since Create Magazine 2.0
     */
    function create_magazine_add_gallery_section() {

        // Check if gallery is enabled 
        $gallery_enable = apply_filters( 'create_magazine_section_status', true, 'gallery_enable' );
        
        if ( true !== $gallery_enable ) {
            return false;
        }

        // Get gallery section details
        $section_details = array();
        $section_details = apply_filters( 'create_magazine_filter_gallery_section_details', $section_details );


        if ( empty( $section_details ) ) {
            return;
        }

        // Render gallery section now.
        create_magazine_photo_gallery_section( $section_details );
    }
endif;
add_action( 'create_magazine_primary_content', 'create_magazine_add_gallery_section', 90 );


if ( ! function_exists( 'create_magazine_get_gallery_section_details' ) ) :
    /**
     * Gallery section details.
     *
     * @since Create Magazine 2.0
     *
     * @param array $input Gallery section details.
     */
    function create_magazine_get_gallery_section_details( $input ) {
        $options = create_magazine_get_theme_options();

        // Gallery type
        $cm_gallery = $options['gallery_type'];

        $content = array();
        switch ( $cm_gallery ) {

            case 'custom':
                $no_of_images = absint( $options['num_gallery_image'] );
                
                for ( $i = 1; $i <= $no_of_images ; $i++) { 
                    if ( function_exists( 'create_magazine_get_attachment_id_from_src' ) ) {
                        $image_id = ! empty( $options['gallery_image_' . $i] ) ? create_magazine_get_attachment_id_from_src( $options['gallery_image_' . $i] ) : "";
                    }
                    if ( ! empty( $image_id ) ) :
                        $image = wp_get_attachment_image_src( $image_id, 'create-magazine-photo-gallery' );
                        $large_image = wp_get_attachment_image_src( $image_id, 'full' );

                        $alt = ! empty( $options['gallery_image_alt_' . $i] ) ? $options['gallery_image_alt_' . $i] : '';

                        $content[$i]['img_html'] = '<a href="' . esc_url( $large_image[0] ) . '" rel="prettyPhoto[gallery1]"><img src="' . esc_url( $image[0] ) . '" alt="' . esc_attr( $alt ) . '"></a>';
                    endif;
                }
                if ( ! empty( $content ) ) {
                    $input = $content;
                }
            break;

            case 'demo':
                for ( $i = 1; $i <= 4 ; $i++ ) { 
                    $content[$i]['img_html'] = '<a href="' . get_template_directory_uri() . '/assets/images/photo-gallery-0' . $i . '.jpg" rel="prettyPhoto[gallery1]"><img src="' . get_template_directory_uri() . '/assets/images/photo-gallery-0' . $i . '.jpg" alt="' . esc_attr__( 'logo-image', 'create-magazine' ) . '"></a>';
                }

                if ( ! empty( $content ) ) {
                    $input = $content;
                }
            break;

            default:
            break;
        }
        return $input;

    }
endif;

// Gallery section content details.
add_filter( 'create_magazine_filter_gallery_section_details', 'create_magazine_get_gallery_section_details' );

if ( ! function_exists( 'create_magazine_photo_gallery_section' ) ) :
    /**
     * Add photo gallery section
     *
     * @since Create Magazine 2.0
     */
    function create_magazine_photo_gallery_section( $content_details = array() ) { 
        $options   = create_magazine_get_theme_options();

        $gallery_title = 'demo' == $options['gallery_type'] ?  esc_html__( 'Photo Gallery', 'create-magazine' ) : $options['gallery_title'];
        $title_link = ! empty( $options['gallery_title_url'] ) ? $options['gallery_title_url'] : '';
?>

        <section id="photo-gallery" class="bg-light-red">
            <div class="container page-section">
                <?php if(! empty( $gallery_title ) ) : ?>
                <header class="entry-header text-left">
                    <h2 class="entry-title color-white os-animation" data-os-animation="fadeInDown" data-os-animation-delay="0.3s" data-os-animation-duration="1s">
                        <a href="<?php echo esc_url( $title_link ); ?>">
                            <?php echo esc_html( $gallery_title ); ?>
                        </a>
                    </h2>
                </header>
                <?php endif; ?>
                <?php
                    $carousel_visible_count = count($content_details);
                    if ( $carousel_visible_count >= 4 ) 
                        $carousel_visible_count = 4;
                    else 
                        $carousel_visible_count ;
                ?>
                <div class="entry-content">
                    <div class="cycle-slideshow gallery" data-cycle-auto-height="calc" data-cycle-timeout="3000" data-cycle-fx="carousel" data-cycle-carousel-fluid="true" data-cycle-carousel-visible="<?php echo absint( $carousel_visible_count ); ?>" data-cycle-slides=">a" data-cycle-next=".cycle-next-4" data-cycle-prev=".cycle-prev-4">
                        <?php 
                        foreach ( $content_details as $content ) :
                            echo $content['img_html'];
                        endforeach; 
                        ?>
                        
                    </div><!-- end .cycle-slideshow -->

                    <div class="controls">
                        <div class="cycle-prev-4"><a href="#"><i class="fa fa-caret-left"></i></a></div>
                        <div class="cycle-next-4"><a href="#"><i class="fa fa-caret-right"></i></a></div>
                    </div><!--end controls -->

                </div><!-- end entry-content -->
            </div><!-- end .container -->
        </section><!--end #photo-gallery -->
    <?php
    }
endif;
