<?php
/**
 * Recent story section
 *
 * This is the template for the content of recent story section
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */

if ( ! function_exists( 'create_magazine_add_recent_story_section' ) ) :
    /**
     * Add recent story section
     *
     * @since 2.0
     */
    function create_magazine_add_recent_story_section() {
        // Check if recent story is enabled on frontpage
        $recent_story_enable = apply_filters( 'create_magazine_section_status', true, 'recent_story_enable' );

        if ( true !== $recent_story_enable ) {
            return false;
        }

        // Get recent story section details
        $section_details = array();
        $section_details = apply_filters( 'create_magazine_filter_recent_story_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render recent story now.
       create_magazine_render_recent_story_section_details( $section_details );
    }
endif;
add_action( 'create_magazine_primary_content', 'create_magazine_add_recent_story_section', 30 );

if ( ! function_exists( 'create_magazine_get_recent_story_section_details' ) ) :
    /**
     * About category block one details.
     *
     * @since 2.0
     *
     * @param array $input category block one section details.
     */
    function create_magazine_get_recent_story_section_details( $input ) {
        $options = create_magazine_get_theme_options();

        // Category block one type
        $content_type = $options['recent_story_content_type'];
        $content      = array();

        switch ( $content_type ) {

            case 'demo':
                $no_of_posts  = 3;
                $titles = array( esc_html__( 'Lil Wayne sues TheUniversal Music over unpaid royalties','create-magazine' ), esc_html__( 'Gaming streaming service Pandora brings back founder','create-magazine' ), esc_html__( 'Somp Justin Bieber deal is not just another gimmick events on rock','create-magazine' ) );// An array of demo title
                $images = array( 'recent-story-01.jpg', 'recent-story-02.jpg', 'recent-story-03.jpg' ); // An array of demo images
                $terms  = array( esc_html__('Lifestyle','create-magazine'), esc_html__('Gaming','create-magazine'), esc_html__('Music','create-magazine'), ); // An array of demo category

                for ( $index = 0; $index < $no_of_posts; $index++ ) {
                    $content[$index]['img_array']= array( get_template_directory_uri(). '/assets/images/'. $images[$index] ); 
                    $content[$index]['url']      = '#';
                    $content[$index]['title']    = $titles[$index];
                    $content[$index]['terms']    = $terms[$index];
                    $content[$index]['date']     = esc_html__( 'FEB 22, 2016', 'create-magazine' );
                }
            break;

            case 'all-category':
                $no_of_posts = 3;

                    $qargs = array(
                        'posts_per_page' => $no_of_posts,
                        'orderby'        => 'date'
                    );
            break;

            default:
            break;
        }

        if( 'demo' !=   $content_type ){
            if( !empty( $qargs ) ){
                // Fetch posts.
                $custom_posts = get_posts( $qargs );
                $index = 0;

                foreach ( $custom_posts as $key => $custom_post ) {

                    if ( has_post_thumbnail( $custom_post->ID ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'create-magazine-recent-storys' );

                        $content[$index]['img_array'] = $img_array;
                    }

                    $content[$index]['url']   = get_permalink( $custom_post->ID );
                    $content[$index]['title'] = $custom_post->post_title;
                    $content[$index]['terms'] = get_the_category( $custom_post->ID );
                    $content[$index]['date']  = get_the_date( '', $custom_post->ID );

                    $index ++;
                }
            }
        }

        if ( ! empty( $content ) ) {
            $input =  $content;
        }
        return $input;
    }
endif;
// Category section one content details.
add_filter( 'create_magazine_filter_recent_story_section_details', 'create_magazine_get_recent_story_section_details' );

if ( ! function_exists( 'create_magazine_render_recent_story_section_details' ) ) :
    /**
     * Start section id #recent-story
     *
     * @return string about content
     * @since Create Magazine 2.0
     *
     */
    function create_magazine_render_recent_story_section_details( $section_details = array() ) {
        $options = create_magazine_get_theme_options();

        // Recent story type
        $content_type = $options['recent_story_content_type'];

        if ( empty( $section_details ) ) {
            return;
        } 
        ?>
        <article id="recent-story">
            <div class="container page-section no-padding-bottom">
                <?php  
                    $recent_story_title = ( 'demo' != $content_type ) ? $options['recent_story_title'] : esc_html__( 'Recent Story', 'create-magazine');

                    if( !empty( $recent_story_title ) ):
                ?>
                <div class="entry-header text-center os-animation" data-os-animation="fadeInDown" data-os-animation-delay="0.1s" data-os-animation-duration="1s">
                    <h2 class="entry-title color-black"><?php echo esc_html( $recent_story_title ); ?> </h2>
                </div><!-- end .entry-header -->
                <?php endif; ?>
                <div class="entry-content three-col">
                    <div class="row">

                    <?php foreach( $section_details as $section_detail ) :
                            $recent_story_post_thumbnail =  isset( $section_detail['img_array'] ) ? $section_detail['img_array'] : '';
                            $recent_story_post_terms     = $section_detail['terms'];
                            $class = isset( $section_detail['img_array'] ) ? '' : ' no-post-thumbnail';
                    ?>
                        <div class="column-wrapper os-animation<?php echo esc_attr( $class ); ?>" data-os-animation="fadeIn" data-os-animation-delay="0.3s" data-os-animation-duration="1s">

                        <?php if( !empty( $recent_story_post_thumbnail ) ) : ?>
                            <div class="blog-image">
                                <?php echo '<a href="'. esc_url( $section_detail['url'] ) .'"><img src="'. esc_url( $recent_story_post_thumbnail[0] ) .'" alt="'. esc_html( $section_detail['title'] ) .'"></a>'; ?>
                            </div><!-- end .blog-image -->
                        <?php endif; ?>
                        
                            <div class="recent-story-wrapper">

                            <?php  if( 'demo' == $content_type ){
                                        echo '<div class="tag"><a href="#"><span class="bg-grey" data-hover="'. esc_attr( $recent_story_post_terms ).'">'. esc_html( $recent_story_post_terms ).'</span></a></div><!-- end .tag -->';       
                                    } else{
                                        $bg_color = create_magazine_background_color(); // get background color array
                                        $i = 0;
                                        foreach( $recent_story_post_terms as $post_category ){
                                            echo '<div class="tag"><a href="'. esc_url( get_category_link( $post_category->term_id ) ) .'"><span class="'. esc_attr( $bg_color[$i] ) .'" data-hover="'. esc_attr( $post_category->name ).'">'. esc_html( $post_category->name ).'</span></a></div><!-- end .tag -->';

                                            if( $i == 2){ break; } // show only three category
                                            $i++;
                                        }
                                    }
                            ?> 
                                <a href="<?php echo esc_url( $section_detail['url'] ); ?>"><h3><?php echo esc_html( $section_detail['title'] ); ?></h3></a>
                                <span class="date"><?php echo esc_html( $section_detail['date'] ); ?></span>
                            </div><!-- end .recent-story-wrapper -->
                        </div><!--end .column-wrapper -->
                    <?php endforeach; ?>
                     </div><!-- end row-->
                    <div class="clear"></div>
                </div><!-- end .entry-content -->
            </div><!-- end .container -->
        </article><!-- end .recent-story -->
    <?php
    }
endif;