<?php
/**
 * Top categories section
 *
 * This is the template for the content of top categories section
 *
 * @package Theme Palace
 * @subpackage Create_Magazine
 * @since Create Magazine 2.0
 */

if ( ! function_exists( 'create_magazine_add_top_categories' ) ) :
    /**
     * Add top categories section
     *
     * @since 2.0
     */

    function create_magazine_add_top_categories() { 

        // Check if top categories is enabled on frontpage
        $top_categories_enable = apply_filters( 'create_magazine_section_status', true, 'top_categories_enable' );

        if ( true !== $top_categories_enable ) {
            return false;
        }

        $options = create_magazine_get_theme_options(); // get theme options
        $content_type = $options['top_categories_content_type'];

        if( 'demo' ==  $content_type ){
            $top_categories_section_title = 'Top Categories';
        } else {
            $top_categories_section_title = $options['top_categories_title'];
        }

        $top_categories = '
            <section id="top-categories" class="bg-white">';

                if( !empty( $top_categories_section_title ) ) {
                    $top_categories .= '
                    <header class="container entry-header text-left">
                        <h2 class="entry-title color-black os-animation" data-os-animation="fadeInDown" data-os-animation-delay="0.1s" data-os-animation-duration="1s">'. esc_html( $top_categories_section_title ) .'</h2>
                    </header>';
                }

                $top_categories .= '
                
                <div class="entry-content bg-red">
                    <div class="container">';
                        if( 'demo' == $content_type && function_exists( 'create_magazine_top_categories_demo_details' ) ){
                            $top_categories .=  create_magazine_top_categories_demo_details();
                        }
                        elseif( 'category' == $content_type && function_exists( 'create_magazine_top_categories_category_details' ) ){
                            $top_categories .=  create_magazine_top_categories_category_details( $options );
                        }
                $top_categories .= '
                        <div class="clear"></div>
                    </div><!-- end .container -->
                </div><!-- end .entry-content -->
            </section><!-- end #top-categories -->';
        echo  $top_categories;
    }
endif;
add_action( 'create_magazine_primary_content', 'create_magazine_add_top_categories', 70 );

/*
 * Add demo details for top categories section
 */

function create_magazine_top_categories_demo_details() {
    
    $top_categories_demo_content = '
        <div class="pull-left">
            <figure class="os-animation" data-os-animation="fadeIn" data-os-animation-delay="0.1s" data-os-animation-duration="1s">    
                <a href="#"><img src="'. get_template_directory_uri(). '/assets/images/top-category-01.jpg"></a>
                    <figcaption><a href="#">'.esc_html__('Travel','create-magazine').'</a></figcaption>  
            </figure>
        </div><!-- end .pull-left -->

        <div class="pull-left">
            <figure class="os-animation" data-os-animation="fadeIn" data-os-animation-delay="0.1s" data-os-animation-duration="1s">    
                <a href="#"><img src="'. get_template_directory_uri() .'/assets/images/top-category-02.jpg"></a>
                    <figcaption><a href="#">'.esc_html__('Music','create-magazine').'</a></figcaption>  
            </figure>
            <figure class="os-animation" data-os-animation="fadeIn" data-os-animation-delay="0.1s" data-os-animation-duration="1s">    
                <a href="#"><img src="'. get_template_directory_uri() .'/assets/images/top-category-03.jpg"></a>
                    <figcaption><a href="#">'.esc_html__('Food','create-magazine').'</a></figcaption>  
            </figure>
        </div><!-- end .pull-left -->

        <div class="pull-left">
            <figure class="post-video os-animation" data-os-animation="fadeIn" data-os-animation-delay="0.4s" data-os-animation-duration="1s">    
                <a href="https://www.youtube.com/watch?v=yQOVcP67zFM" rel="prettyPhoto">
                    <span class="btn btn-play"><i class="fa fa-play"></i></span>
                    <img src="'. get_template_directory_uri() .'/assets/images/wildlife.jpg" alt="'. esc_attr__( 'video-image','create-magazine').'">
                </a>
                <figcaption><a href="#">'.esc_html__('Wildlife','create-magazine').'</a></figcaption>  
            </figure>
        </div><!-- end .pull-left -->';

    return $top_categories_demo_content;
}

/*
* Add category content type details for top categories section
 */
function create_magazine_top_categories_category_details( $options ){
    
    $top_categories_category_content = '';
    $no_of_category = absint( $options['top_categories_no_of_posts'] );
    $category_contents = array();

    for( $i = 1; $i <= $no_of_category; $i ++ ){
        if( !empty( $options['top_categories_content_category_'. $i ] ) && $options['top_categories_content_category_'. $i ] > 0 ){
            $category_contents[$i]['cat_id'] = absint( $options['top_categories_content_category_'. $i ] );
        }
        if( !empty( $options['top_categories_image_'. $i ] ) ){
            $category_contents[$i]['img_url'] = $options['top_categories_image_'. $i ];
        }
    }
    if( empty( $category_contents ) ){
        return;
    }
    $category_length = count( $category_contents );

    $count = 1;
   
    $top_categories_category_content .= '<div class="pull-left">';
    foreach( $category_contents as $category_content ){ 
        if( isset( $category_content['cat_id'] ) ){
            $category_name = get_cat_name( $category_content['cat_id'] );
            $category_url  = get_category_link( $category_content['cat_id'] ); 
        } else {
            $category_name = '';
            $category_url  = '';
        }
        switch ( $category_length ) {
            case 1:
                $thumbnail_size = 'create-magazine-top-categories-large';
                $default_img_size = '424x318';
                break;

            case 2:
                $thumbnail_size = 'create-magazine-top-categories-medium';
                $default_img_size = '318x318';
                break;
            
            case 3:                
                $thumbnail_size = 'create-magazine-top-categories-large';
                $default_img_size = '424x318';                
                break;

            default:
                break;
        }

        if( isset( $category_content['img_url'] ) ){
            $image_id = create_magazine_get_attachment_id_from_src( $category_content['img_url'] );
            $image_array = wp_get_attachment_image_src( $image_id, $thumbnail_size );
            $image_src = $image_array[0];
        }else{
            $image_src = get_template_directory_uri().'/assets/images/no-featured-image-' . $default_img_size . '.jpg';
        }

        $top_categories_category_content .= '
                <figure class="os-animation" data-os-animation="fadeIn" data-os-animation-delay="0.1s" data-os-animation-duration="1s">    
                    <a href="'. esc_url( $category_url ) .'"><img src="'. esc_url( $image_src ) .'"></a>
                        <figcaption><a href="'. esc_url( $category_url ) .'">'. esc_html(  $category_name ) .'</a></figcaption>  
                </figure>';
        if ( $count == 1 ) :
            $top_categories_category_content .= '</div><!-- end .pull-left --><div class="pull-left">';
        endif;

        $count ++;
    }
    $top_categories_category_content .= '</div><!-- end .pull-left -->';
    $top_categories_category_content .= '<div class="pull-left">';
    if ( is_active_sidebar( 'top-categories-widget' ) ) {
        ob_start();
        dynamic_sidebar('top-categories-widget');
        $top_categories_category_content .= ob_get_contents();
        ob_end_clean();
    }
    $top_categories_category_content .= '</div><!-- end .pull-left -->';
    return $top_categories_category_content;
}
